@@ -2,7 +2,7 @@ package PICA::Data;
 use strict;
 use warnings;
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(pica_parser pica_writer pica_path pica_xml_struct
@@ -210,6 +210,7 @@ PICA::Data - PICA record processing
     $parser = PICA::Parser::XML->new( @options );
     $writer = PICA::Writer::Plain->new( @options );
 
+    # parse records
     while ( my $record = $parser->next ) {
         
         # function accessors
@@ -225,6 +226,8 @@ PICA::Data - PICA record processing
         my $items    = $record->items;
         ...
 
+        # write record
+        $writer->write($record);
     }
   
     # parse single record from string
@@ -242,7 +245,7 @@ Austauschformat fuer Bibliotheken (MAB). In addition to PICA+ in CBS there is
 the cataloging format Pica3 which can losslessly be convert to PICA+ and vice
 versa.
 
-Records in PICA::Data are encoded either as as array of arrays, the inner
+Records in PICA::Data are encoded either as array of arrays, the inner
 arrays representing PICA fields, or as an object with two fields, C<_id> and
 C<record>, the latter holding the record as array of arrays, and the former
 holding the record identifier, stored in field C<003@>, subfield C<0>. For
@@ -288,6 +291,11 @@ L<PICA::Parser::Plain> for type C<plain> or C<picaplain> (human-readable PICA+)
 
 =back
 
+=head2 pica_xml_struct( $xml, %options )
+
+Convert PICA-XML, expressed in L<XML::Struct> structure into an (optionally
+blessed) PICA record structure.
+
 =head2 pica_writer( $type [, @options] )
 
 Create a PICA writer object in the same way as C<pica_parser> with one of
@@ -310,22 +318,32 @@ L<PICA::Writer::Plain> for type C<plain> or C<picaplain> (human-readable PICA+)
 
 =head2 pica_path( $path )
 
-Equivalent to L<<PICA::Path->new($path)|PICA::Path>>.
+Equivalent to L<PICA::Path>-E<gt>new($path).
 
 =head2 pica_values( $record, $path )
 
+Extract a list of subfield values from a PICA record based on a PICA path
+expression. Also available as accessor C<values($path)>.
+
 =head2 pica_value( $record, $path )
 
+Extract the first subfield values from a PICA record based on a PICA path
+expression. Also available as accessor C<value($path)>.
+
 =head2 pica_fields( $record, $path )
 
+Returns a PICA record (or empty array reference) limited to fields specified in
+a PICA path expression. Also available as accessor C<fields($path)>.
+
 =head2 pica_holdings( $record )
 
-=head2 pica_head2s( $record )
+Returns a list (as array reference) of local holding records. Also available as
+accessor C<holdings>.
 
-=head2 pica_xml_struct( $xml, %options )
+=head2 pica_items( $record )
 
-Convert PICA-XML, expressed in L<XML::Struct> structure into an (optionally
-blessed) PICA record structure.
+Returns a list (as array reference) of item records. Also available as
+accessor C<items>.
 
 =head1 ACCESSORS
 
